aboutsummaryrefslogtreecommitdiff
path: root/backends/fs/palmos/palmos-fs-factory.h
diff options
context:
space:
mode:
Diffstat (limited to 'backends/fs/palmos/palmos-fs-factory.h')
-rw-r--r--backends/fs/palmos/palmos-fs-factory.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/backends/fs/palmos/palmos-fs-factory.h b/backends/fs/palmos/palmos-fs-factory.h
index 9d873eeb12..3ea8b5fe47 100644
--- a/backends/fs/palmos/palmos-fs-factory.h
+++ b/backends/fs/palmos/palmos-fs-factory.h
@@ -26,14 +26,14 @@
#define PALMOS_FILESYSTEM_FACTORY_H
#include "common/singleton.h"
-#include "backends/fs/abstract-fs-factory.h"
+#include "backends/fs/fs-factory.h"
/**
* Creates PalmOSFilesystemNode objects.
*
* Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
*/
-class PalmOSFilesystemFactory : public AbstractFilesystemFactory, public Common::Singleton<PalmOSFilesystemFactory> {
+class PalmOSFilesystemFactory : public FilesystemFactory, public Common::Singleton<PalmOSFilesystemFactory> {
public:
typedef Common::String String;
@@ -26,14 +26,14 @@
* Creates PalmOSFilesystemNode objects.
*
- * Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
+ * Parts of this class are documented in the base interface class, FilesystemFactory.
*/